@@ -8,10 +8,14 @@
 #endif
 
 #ifdef _WIN32
-PyMODINIT_FUNC PyInit__fps(void) { return NULL; }
+#ifdef WITH_CUDA
+PyMODINIT_FUNC PyInit__fps_cuda(void) { return NULL; }
+#else
+PyMODINIT_FUNC PyInit__fps_cpu(void) { return NULL; }
+#endif
 #endif
 
-torch::Tensor fps(torch::Tensor src, torch::Tensor ptr, double ratio,
+torch::Tensor fps(torch::Tensor src, torch::Tensor ptr, torch::Tensor ratio,
                   bool random_start) {
   if (src.device().is_cuda()) {
 #ifdef WITH_CUDA
